#
# generate PSF and initial pdb w/ correct covalent geometry for
#
# a circular peptide with sequence
#   GLY MET SERP ILE TYRP VAL ALA CYS
#
# where SERP and TYRP stand for phosphoserine, and phosphotyrosine,
#  respectively. 
#
#
xplor.parseArguments() # check for typos on the command-line

seq = " GLY MET SER ILE TYR VAL ALA CYS"

import psfGen
psfGen.seqToPSF(seq)

import protocol
protocol.initTopology("pho.top")
protocol.initParams("pho.par")

xplor.command("""
topology
AUTO ANGLe=False DIHEdral=False END

! circular link
 presidue CYSC  

    delete    atom +N               end
    delete    atom +HT1               end
    delete    atom +HT2               end
    delete    atom +HT3               end
    delete    atom -HG               end

  add bond -SG +CA

  add angle -SG +CA +C
  add angle -CB -SG +CA

  add improper +HA1 +HA2 -SG +C  !stereo CA
  
end 

!modified  C-terminus
presidue CTN1                  ! 
  group
    modify    atom -C           charge= 0.48 end
    modify    atom -OT1          charge=-0.48 end
    delete    atom -OT2  end
    add       atom -NT type=NH2 charge=-0.52 end
    add       atom -H1 type=H   charge= 0.26 end
    add       atom -H2 type=H   charge= 0.26 end

  add bond -C  -NT
  add bond -NT -H1
  add bond -NT -H2

  add angle -CA -C  -NT
  add angle -OT1  -C  -NT
  add angle -CA -C  -OT1
  add angle -C  -NT -H1
  add angle -C  -NT -H2
  add angle -H1 -NT -H2

  add improper -C  -CA -NT -OT1
  add improper -C  -NT -OT1  -H1
  add improper -NT -H1 -H2 -C
end

end

!add the PHO groups 
segment
 setup=true
 number=9
 chain
   sequence PHO PHO end
 end
end


para
 angle     S CT C            $kang     109.5 ! tetrahedral psf new.psf pdb new.pdb

 improper  HA   HA   S  C     $kchi   0   -70.874  ! stereo GLY CA

 angle     NH2  C    OC             $kang     120.6
 
end


!make cyclic link
 patch CYSC reference=-=(resid 8) reference=+=(resid 1) end
!modifify c-terminus
 patch CTN1  reference=-=(resid 8) end
!phosphorylate residues
 patch SP reference=1=(resid 3) reference=2=(resid 9) end
 patch YP reference=1=(resid 5) reference=2=(resid 10) end
""")

psfGen.cisPeptide(3)



xplor.command("write psf output=circ.psf end")

import protocol
protocol.initRandomSeed()
protocol.addUnknownAtoms(dyn_stepsize=0.012,dyn_numStepMul=2)

for i in range(4):
    try:
        protocol.fixupCovalentGeom(useVDW=1,maxIters=400)
        break
    except Exception, e:
        if e.args[0].startswith("Covalent geometry still violated"):
            continue
        raise
    pass



from pdbTool import PDBTool
PDBTool("circ.pdb").write()
