#!/usr/bin/env pyXplor

#
# script to generate psf and parameter files for a HETATM residue
# currently, CONECT records are not read, so the whole residue (ligand)
# must be grouped as a rigid body
#

(opts,pdbFiles) = xplor.parseArguments(('resid:1',
                                        'segid:1',
                                        'help-script:0'))

resid=None
segid='    '

for opt in opts:
    if opt[0]=='resid':
        resid=int(opt[1])
        pass
    if opt[0]=='segid':
        segid=opt[1]
        pass
    pass

nonbondParams=dict(
  C   =    (0.145   ,  3.2072  ,    0.145  ,  3.2072),
  H   =    (0.0498  ,  1.4254  ,    0.0498 ,  1.4254),
  N   =    (0.1592  ,  2.7618  ,    0.1592 ,  2.7618),
  O   =    (0.2342  ,  2.6406  ,    0.2342 ,  2.6406),
  S   =    (0.0239  ,  3.3854  ,    0.0239 ,  3.3854),
  )

pdbFile=pdbFiles[0]


def pdbToResInfo(pdbRecord,
                 targetResid=None,
                 targetSegid='',
                 useChainID=True,
                 ):
    """ read pdb record and extract atom info.

    TODO: extract CONECT records

    If useChainID is set, chainID overrides segment name, if it is set.
    """
    ret = []
    curResname=None
    terminate=0
    seg='    '
    previousTerminate=0 #true if one termination atom has been seen
    lines=pdbRecord.split('\n')
    for line in lines:
        if line.startswith('ATOM') or line.startswith('HETATM'): 
            resname = line[17:21]
            resid = int(line[22:26])
            if targetResid==None: targetResid=resid
            if targetResid != resid:
                continue


            seg = line[72:76]
            seg += ' '*(4-len(seg)) # this for truncated ATOM records
            chainID=line[21]
            if (useChainID or seg=='' or seg=='    ') and chainID!=' ':
                seg = chainID
                pass

            #print resid, targetResid, ">%s<" %seg, ">%s<" %targetSegid

    

            if seg != targetSegid:
                continue

            if curResname==None: curResname=resname

            if curResname!=resname:
                raise("curResname!=res: %s != %s" % (curResname,resname))

            name = line[12:16].strip()

            record=(resid,resname,name,segid)
            ret.append( record )
            pass
        pass
            
    return ret



entry= pdbToResInfo(open(pdbFile).read(),resid,segid)

print len(entry),entry

(resid,resname,name,segid)=entry[0]

residue="residue %s\n" % resname
mass=""
params="""
! auto-generated by genLigand.py
"""
for (resid,resname,name,segid) in entry:
    element=name[0].upper()
    if not element in nonbondParams.keys():
        print "could not find nonbonded parameters for atom named",name
        print "  omitted."
        continue
    params += 'nonbonded "G%s" ' % name
    params += "%.4f %.4f %.4f %.4f\n" % nonbondParams[element]
    residue += '  atom "%s" type="G%s" end\n' % (name,name)
    mass += 'mass "G%s" 100\n' % name
    pass
residue+="end\n"


xplor.command("topology %s end" % mass)
xplor.command("topology %s end" % residue)

xplor.command('''
      REMARKS  autogenerated by genLigand.py
      segment
        name="%s"
        SETUP=TRUE
        number=%d
        chain
          sequence %s end
        end
      end
''' % (segid,resid,resname))


psfFilename=resname.strip() + ".psf"
paramFilename=resname.strip() + ".par"

open(paramFilename,"w").write(params)
    
xplor.command("write psf output=%s end" % psfFilename)


